@@ -3,8 +3,11 @@ import requests
 from .models import Users
 from .models import Projects
 from .models import UserStories
+from .models import UserStoryAttachments
 from .models import Tasks
+from .models import TaskAttachments
 from .models import Issues
+from .models import IssueAttachments
 from .models import Milestones
 from .models import Points
 from .models import UserStoryStatuses
@@ -35,19 +38,25 @@ class SearchResult(object):
 
 class TaigaAPI:
 
-    def __init__(self, host='https://api.taiga.io', token=None):
+    def __init__(self, host='https://api.taiga.io', token=None,
+                 token_type='Bearer'):
         self.host = host
         self.token = token
+        self.token_type = token_type
         if token:
-            self.raw_request = RequestMaker('/api/v1', self.host, self.token)
+            self.raw_request = RequestMaker('/api/v1', self.host, self.token,
+                                            self.token_type)
             self._init_resources()
 
     def _init_resources(self):
         self.projects = Projects(self.raw_request)
         self.user_stories = UserStories(self.raw_request)
+        self.user_story_attachments = UserStoryAttachments(self.raw_request)
         self.users = Users(self.raw_request)
         self.issues = Issues(self.raw_request)
+        self.issue_attachments = IssueAttachments(self.raw_request)
         self.tasks = Tasks(self.raw_request)
+        self.task_attachments = TaskAttachments(self.raw_request)
         self.milestones = Milestones(self.raw_request)
         self.severities = Severities(self.raw_request)
         self.roles = Roles(self.raw_request)
@@ -101,15 +110,69 @@ class TaigaAPI:
         except RequestException:
             raise exceptions.TaigaRestException(
                 full_url, 400,
-                'NETWORK ERROR', 'GET'
+                'NETWORK ERROR', 'POST'
             )
         if response.status_code != 200:
             raise exceptions.TaigaRestException(
                 full_url,
                 response.status_code,
                 response.text,
-                'GET'
+                'POST'
             )
         self.token = response.json()['auth_token']
-        self.raw_request = RequestMaker('/api/v1', self.host, self.token)
+        self.raw_request = RequestMaker('/api/v1', self.host, self.token,
+                                        'Bearer')
+        self._init_resources()
+
+    def auth_app(self, app_id, app_secret, auth_code, state=''):
+        headers = {
+            'Content-type': 'application/json'
+        }
+        payload = {
+            'application': app_id,
+            'auth_code': auth_code,
+            'state': state
+        }
+        try:
+            full_url = self.host + '/api/v1/application-tokens/validate'
+            response = requests.post(
+                full_url,
+                data=json.dumps(payload),
+                headers=headers
+            )
+        except RequestException:
+            raise exceptions.TaigaRestException(
+                full_url, 400,
+                'NETWORK ERROR', 'POST'
+            )
+        if response.status_code != 200:
+            raise exceptions.TaigaRestException(
+                full_url,
+                response.status_code,
+                response.text,
+                'POST'
+            )
+        cyphered_token = response.json().get('cyphered_token', '')
+        if cyphered_token:
+            from jwkest.jwk import SYMKey
+            from jwkest.jwe import JWE
+
+            sym_key = SYMKey(key=app_secret, alg='A128KW')
+            (data, success) = JWE().decrypt(cyphered_token, keys=[sym_key])
+            if success:
+                self.token = json.loads(data.decode('utf-8')).get('token',
+                                                                  None)
+            else:
+                self.token = None
+        else:
+            self.token = None
+
+        if self.token is None:
+            raise exceptions.TaigaRestException(
+                full_url, 400,
+                'INVALID TOKEN', 'POST'
+            )
+
+        self.raw_request = RequestMaker('/api/v1', self.host, self.token,
+                                        'Application')
         self._init_resources()
