@@ -1,6 +1,11 @@
 import datetime
 from .base import InstanceResource, ListResource
-from taiga.exceptions import TaigaException
+
+
+class CommentableReosource(InstanceResource):
+
+    def add_comment(self, comment):
+        return self.update(comment=comment)
 
 
 class CustomAttributeResource(InstanceResource):
@@ -8,12 +13,7 @@ class CustomAttributeResource(InstanceResource):
     def set_attribute(self, id, value, version=1):
         attributes = self.get_attributes()
         formatted_id = '{0}'.format(id)
-        if formatted_id in attributes['attributes_values']:
-            attributes['attributes_values'][formatted_id] = value
-        else:
-            raise TaigaException(
-                'Attribute with id {0} doesn\'t exist'.format(formatted_id)
-            )
+        attributes['attributes_values'][formatted_id] = value
         response = self.requester.patch(
             '/{endpoint}/custom-attributes-values/{id}',
             endpoint=self.endpoint, id=self.id,
@@ -137,14 +137,14 @@ class UserStoryAttachments(Attachments):
     instance = UserStoryAttachment
 
 
-class UserStory(CustomAttributeResource):
+class UserStory(CustomAttributeResource, CommentableReosource):
 
     endpoint = 'userstories'
 
     repr_attribute = 'subject'
 
     allowed_params = [
-        'assigned_to', 'backlog_order', 'blocked_note',
+        'assigned_to', 'backlog_order', 'blocked_note', 'version',
         'client_requirement', 'description', 'is_archived', 'is_blocked',
         'is_closed', 'kanban_order', 'milestone', 'points', 'project',
         'sprint_order', 'status', 'subject', 'tags', 'team_requirement',
@@ -154,12 +154,15 @@ class UserStory(CustomAttributeResource):
     def add_task(self, subject, status, **attrs):
         return Tasks(self.requester).create(
             self.project, subject, status,
-            user_story=self.id
+            user_story=self.id, **attrs
         )
 
     def list_tasks(self):
         return Tasks(self.requester).list(user_story=self.id)
 
+    def list_attachments(self):
+        return UserStoryAttachments(self.requester).list(object_id=self.id)
+
     def attach(self, attached_file, **attrs):
         return UserStoryAttachments(self.requester).create(
             self.project, self.id,
@@ -175,6 +178,19 @@ class UserStories(ListResource):
         attrs.update({'project': project, 'subject': subject})
         return self._new_resource(payload=attrs)
 
+    def import_(self, project, subject, status, **attrs):
+        attrs.update(
+            {
+                'project': project,
+                'subject': subject,
+                'status': status
+            }
+        )
+        response = self.requester.post('/{endpoint}/{id}/{type}',
+                                       endpoint="importer", id=project,
+                                       type="us", payload=attrs)
+        return self.instance.parse(self.requester, response.json())
+
 
 class UserStoryStatus(InstanceResource):
 
@@ -253,6 +269,23 @@ class Milestones(ListResource):
         })
         return self._new_resource(payload=attrs)
 
+    def import_(self, project, name, estimated_start,
+                estimated_finish, **attrs):
+        if isinstance(estimated_start, datetime.datetime):
+            estimated_start = estimated_start.strftime('%Y-%m-%d')
+        if isinstance(estimated_finish, datetime.datetime):
+            estimated_finish = estimated_finish.strftime('%Y-%m-%d')
+        attrs.update({
+            'project': project,
+            'name': name,
+            'estimated_start': estimated_start,
+            'estimated_finish': estimated_finish
+        })
+        response = self.requester.post('/{endpoint}/{id}/{type}',
+                                       endpoint="importer", id=project,
+                                       type="milestone", payload=attrs)
+        return self.instance.parse(self.requester, response.json())
+
 
 class TaskStatus(InstanceResource):
 
@@ -280,19 +313,22 @@ class TaskAttachments(Attachments):
     instance = TaskAttachment
 
 
-class Task(CustomAttributeResource):
+class Task(CustomAttributeResource, CommentableReosource):
 
     endpoint = 'tasks'
 
     repr_attribute = 'subject'
 
     allowed_params = [
-        'assigned_to', 'blocked_note', 'description',
+        'assigned_to', 'blocked_note', 'description', 'version',
         'is_blocked', 'is_closed', 'milestone', 'project', 'user_story',
         'status', 'subject', 'tags', 'us_order', 'taskboard_order',
         'is_iocaine', 'external_reference', 'watchers'
     ]
 
+    def list_attachments(self):
+        return TaskAttachments(self.requester).list(object_id=self.id)
+
     def attach(self, attached_file, **attrs):
         return TaskAttachments(self.requester).create(
             self.project, self.id,
@@ -313,6 +349,19 @@ class Tasks(ListResource):
         )
         return self._new_resource(payload=attrs)
 
+    def import_(self, project, subject, status, **attrs):
+        attrs.update(
+            {
+                'project': project,
+                'subject': subject,
+                'status': status
+            }
+        )
+        response = self.requester.post('/{endpoint}/{id}/{type}',
+                                       endpoint="importer", id=project,
+                                       type="task", payload=attrs)
+        return self.instance.parse(self.requester, response.json())
+
 
 class IssueType(InstanceResource):
 
@@ -356,18 +405,21 @@ class IssueAttachments(Attachments):
     instance = IssueAttachment
 
 
-class Issue(CustomAttributeResource):
+class Issue(CustomAttributeResource, CommentableReosource):
 
     endpoint = 'issues'
 
     repr_attribute = 'subject'
 
     allowed_params = [
-        'assigned_to', 'blocked_note', 'description',
+        'assigned_to', 'blocked_note', 'description', 'version',
         'is_blocked', 'is_closed', 'milestone', 'project', 'status',
-        'severity', 'priority', 'type', 'subject', 'tags', 'watchers'
+        'severity', 'priority', 'type', 'subject', 'tags', 'watchers',
     ]
 
+    def list_attachments(self):
+        return IssueAttachments(self.requester).list(object_id=self.id)
+
     def upvote(self):
         self.requester.post(
             '/{endpoint}/{id}/upvote',
@@ -404,6 +456,20 @@ class Issues(ListResource):
         )
         return self._new_resource(payload=attrs)
 
+    def import_(self, project, subject, priority, status,
+                issue_type, severity, **attrs):
+        attrs.update(
+            {
+                'project': project, 'subject': subject,
+                'priority': priority, 'status': status,
+                'type': issue_type, 'severity': severity
+            }
+        )
+        response = self.requester.post('/{endpoint}/{id}/{type}',
+                                       endpoint="importer", id=project,
+                                       type="issue", payload=attrs)
+        return self.instance.parse(self.requester, response.json())
+
 
 class IssueAttribute(CustomAttribute):
 
@@ -480,7 +546,7 @@ class Project(InstanceResource):
     ]
 
     parser = {
-        'users': Users,
+        'members': Users,
         'priorities': Priorities,
         'issue_statuses': IssueStatuses,
         'issue_types': IssueTypes,
@@ -498,6 +564,20 @@ class Project(InstanceResource):
         )
         return response.json()
 
+    def like(self):
+        self.requester.post(
+            '/{endpoint}/{id}/like',
+            endpoint=self.endpoint, id=self.id
+        )
+        return self
+
+    def unlike(self):
+        self.requester.post(
+            '/{endpoint}/{id}/unlike',
+            endpoint=self.endpoint, id=self.id
+        )
+        return self
+
     def star(self):
         self.requester.post(
             '/{endpoint}/{id}/star',
@@ -525,6 +605,11 @@ class Project(InstanceResource):
             self.id, subject, **attrs
         )
 
+    def import_user_story(self, subject, status, **attrs):
+        return UserStories(self.requester).import_(
+            self.id, subject, status, **attrs
+        )
+
     def list_user_stories(self):
         return UserStories(self.requester).list(project=self.id)
 
@@ -535,6 +620,13 @@ class Project(InstanceResource):
             issue_type, severity, **attrs
         )
 
+    def import_issue(self, subject, priority, status,
+                     issue_type, severity, **attrs):
+        return Issues(self.requester).import_(
+            self.id, subject, priority, status,
+            issue_type, severity, **attrs
+        )
+
     def list_issues(self):
         return Issues(self.requester).list(project=self.id)
 
@@ -544,6 +636,17 @@ class Project(InstanceResource):
             estimated_finish, **attrs
         )
 
+    def import_milestone(
+            self,
+            name,
+            estimated_start,
+            estimated_finish,
+            **attrs):
+        return Milestones(self.requester).import_(
+            self.id, name, estimated_start,
+            estimated_finish, **attrs
+        )
+
     def list_milestones(self):
         return Milestones(self.requester).list(project=self.id)
 
@@ -559,6 +662,11 @@ class Project(InstanceResource):
     def list_task_statuses(self):
         return TaskStatuses(self.requester).list(project=self.id)
 
+    def import_task(self, subject, status, **attrs):
+        return Tasks(self.requester).import_(
+            self.id, subject, status
+        )
+
     def add_user_story_status(self, name, **attrs):
         return UserStoryStatuses(self.requester).create(self.id, name, **attrs)
 
@@ -600,12 +708,20 @@ class Project(InstanceResource):
             self.id, slug, content, **attrs
         )
 
+    def import_wikipage(self, slug, content, **attrs):
+        return WikiPages(self.requester).import_(
+            self.id, slug, content, **attrs
+        )
+
     def list_wikipages(self):
         return WikiPages(self.requester).list(project=self.id)
 
     def add_wikilink(self, title, href, **attrs):
         return WikiLinks(self.requester).create(self.id, title, href, **attrs)
 
+    def import_wikilink(self, title, href, **attrs):
+        return WikiLinks(self.requester).import_(self.id, title, href, **attrs)
+
     def list_wikilinks(self):
         return WikiLinks(self.requester).list(project=self.id)
 
@@ -642,6 +758,18 @@ class Projects(ListResource):
         attrs.update({'name': name, 'description': description})
         return self._new_resource(payload=attrs)
 
+    def import_(self, name, description, roles, **attrs):
+        attrs.update(
+            {
+                'name': name,
+                'description': description,
+                'roles': roles
+            }
+        )
+        response = self.requester.post('/{endpoint}', endpoint="importer",
+                                       payload=attrs)
+        return self.instance.parse(self.requester, response.json())
+
 
 class WikiAttachment(Attachment):
 
@@ -676,6 +804,13 @@ class WikiPages(ListResource):
         attrs.update({'project': project, 'slug': slug, 'content': content})
         return self._new_resource(payload=attrs)
 
+    def import_(self, project, slug, content, **attrs):
+        attrs.update({'project': project, 'slug': slug, 'content': content})
+        response = self.requester.post('/{endpoint}/{id}/{type}',
+                                       endpoint="importer", id=project,
+                                       type="wiki_page", payload=attrs)
+        return self.instance.parse(self.requester, response.json())
+
 
 class WikiLink(InstanceResource):
 
@@ -694,6 +829,13 @@ class WikiLinks(ListResource):
         attrs.update({'project': project, 'title': title, 'href': href})
         return self._new_resource(payload=attrs)
 
+    def import_(self, project, title, href, **attrs):
+        attrs.update({'project': project, 'title': title, 'href': href})
+        response = self.requester.post('/{endpoint}/{id}/{type}',
+                                       endpoint="importer", id=project,
+                                       type="wiki_link", payload=attrs)
+        return self.instance.parse(self.requester, response.json())
+
 
 class History(InstanceResource):
 
